@@ -4,9 +4,8 @@
 
 #include "base/allocator/partition_allocator/dangling_raw_ptr_checks.h"
 
+#include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/base_export.h"
-#include "base/check.h"
-#include "base/logging.h"
 
 namespace partition_alloc {
 
@@ -16,22 +15,22 @@ DanglingRawPtrReleasedFn* g_dangling_raw_ptr_released_fn = [](uintptr_t) {};
 }  // namespace
 
 DanglingRawPtrDetectedFn* GetDanglingRawPtrDetectedFn() {
-  DCHECK(g_dangling_raw_ptr_detected_fn);
+  PA_DCHECK(g_dangling_raw_ptr_detected_fn);
   return g_dangling_raw_ptr_detected_fn;
 }
 
 DanglingRawPtrDetectedFn* GetDanglingRawPtrReleasedFn() {
-  DCHECK(g_dangling_raw_ptr_released_fn);
+  PA_DCHECK(g_dangling_raw_ptr_released_fn);
   return g_dangling_raw_ptr_released_fn;
 }
 
 void SetDanglingRawPtrDetectedFn(DanglingRawPtrDetectedFn fn) {
-  DCHECK(fn);
+  PA_DCHECK(fn);
   g_dangling_raw_ptr_detected_fn = fn;
 }
 
 void SetDanglingRawPtrReleasedFn(DanglingRawPtrReleasedFn fn) {
-  DCHECK(fn);
+  PA_DCHECK(fn);
   g_dangling_raw_ptr_released_fn = fn;
 }
 
