@@ -8,7 +8,7 @@
 #include "base/allocator/buildflags.h"
 #include "base/allocator/partition_allocator/thread_cache.h"
 
-namespace base {
+namespace partition_alloc::internal {
 
 #if defined(PA_THREAD_CACHE_SUPPORTED)
 
@@ -20,7 +20,7 @@ void DisableThreadCacheForRootIfEnabled(ThreadSafePartitionRoot* root) {
   if (!root || !root->with_thread_cache)
     return;
 
-  internal::ThreadCacheRegistry::Instance().PurgeAll();
+  ThreadCacheRegistry::Instance().PurgeAll();
   root->with_thread_cache = false;
   // Doesn't destroy the thread cache object(s). For background threads, they
   // will be collected (and free cached memory) at thread destruction
@@ -36,13 +36,14 @@ void EnablePartitionAllocThreadCacheForRootIfDisabled(
 
 #if BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
 void DisablePartitionAllocThreadCacheForProcess() {
-  auto* regular_allocator = internal::PartitionAllocMalloc::Allocator();
-  auto* aligned_allocator = internal::PartitionAllocMalloc::AlignedAllocator();
+  auto* regular_allocator = ::base::internal::PartitionAllocMalloc::Allocator();
+  auto* aligned_allocator =
+      ::base::internal::PartitionAllocMalloc::AlignedAllocator();
   DisableThreadCacheForRootIfEnabled(regular_allocator);
   if (aligned_allocator != regular_allocator)
     DisableThreadCacheForRootIfEnabled(aligned_allocator);
   DisableThreadCacheForRootIfEnabled(
-      internal::PartitionAllocMalloc::OriginalAllocator());
+      ::base::internal::PartitionAllocMalloc::OriginalAllocator());
 }
 #endif  // defined(USE_PARTITION_ALLOC_AS_MALLOC)
 
@@ -56,10 +57,10 @@ void SwapOutProcessThreadCacheForTesting(ThreadSafePartitionRoot* root) {
 #if BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
   DisablePartitionAllocThreadCacheForProcess();
 #else
-  PA_CHECK(!internal::ThreadCache::IsValid(internal::ThreadCache::Get()));
+  PA_CHECK(!ThreadCache::IsValid(ThreadCache::Get()));
 #endif  // BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
 
-  internal::ThreadCache::SwapForTesting(root);
+  ThreadCache::SwapForTesting(root);
   EnablePartitionAllocThreadCacheForRootIfDisabled(root);
 
 #endif  // defined(PA_THREAD_CACHE_SUPPORTED)
@@ -72,15 +73,15 @@ void SwapInProcessThreadCacheForTesting(ThreadSafePartitionRoot* root) {
   DisableThreadCacheForRootIfEnabled(root);
 
 #if BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
-  auto* regular_allocator = internal::PartitionAllocMalloc::Allocator();
+  auto* regular_allocator = ::base::internal::PartitionAllocMalloc::Allocator();
   EnablePartitionAllocThreadCacheForRootIfDisabled(regular_allocator);
 
-  internal::ThreadCache::SwapForTesting(regular_allocator);
+  ThreadCache::SwapForTesting(regular_allocator);
 #else
-  internal::ThreadCache::SwapForTesting(nullptr);
+  ThreadCache::SwapForTesting(nullptr);
 #endif  // BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
 
 #endif  // defined(PA_THREAD_CACHE_SUPPORTED)
 }
 
-}  // namespace base
+}  // namespace partition_alloc::internal
