@@ -11,6 +11,7 @@
 #include "base/allocator/partition_allocator/oom.h"
 #include "base/allocator/partition_allocator/page_allocator.h"
 #include "base/allocator/partition_allocator/partition_address_space.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/bits.h"
 #include "base/allocator/partition_allocator/partition_alloc_check.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
@@ -21,7 +22,6 @@
 #include "base/allocator/partition_allocator/reservation_offset_table.h"
 #include "base/allocator/partition_allocator/starscan/pcscan.h"
 #include "base/allocator/partition_allocator/tagging.h"
-#include "base/bits.h"
 #include "build/build_config.h"
 
 #if BUILDFLAG(IS_WIN)
@@ -48,18 +48,17 @@ void RecordAllocOrFree(uintptr_t addr, size_t size) {
 }  // namespace partition_alloc::internal
 #endif  // BUILDFLAG(RECORD_ALLOC_INFO)
 
-namespace base {
+namespace partition_alloc {
 
 #if defined(PA_USE_PARTITION_ROOT_ENUMERATOR)
 
 namespace {
 
-internal::PartitionLock g_root_enumerator_lock;
-
+internal::Lock g_root_enumerator_lock;
 }
 
 template <bool thread_safe>
-internal::PartitionLock& PartitionRoot<thread_safe>::GetEnumeratorLock() {
+internal::Lock& PartitionRoot<thread_safe>::GetEnumeratorLock() {
   return g_root_enumerator_lock;
 }
 
@@ -97,8 +96,7 @@ class PartitionRootEnumerator {
   }
 
   void Register(ThreadSafePartitionRoot* root) {
-    internal::PartitionAutoLock guard(
-        ThreadSafePartitionRoot::GetEnumeratorLock());
+    internal::ScopedGuard guard(ThreadSafePartitionRoot::GetEnumeratorLock());
     root->next_root = partition_roots_;
     root->prev_root = nullptr;
     if (partition_roots_)
@@ -107,8 +105,7 @@ class PartitionRootEnumerator {
   }
 
   void Unregister(ThreadSafePartitionRoot* root) {
-    internal::PartitionAutoLock guard(
-        ThreadSafePartitionRoot::GetEnumeratorLock());
+    internal::ScopedGuard guard(ThreadSafePartitionRoot::GetEnumeratorLock());
     ThreadSafePartitionRoot* prev = root->prev_root;
     ThreadSafePartitionRoot* next = root->next_root;
     if (prev) {
@@ -173,7 +170,7 @@ void BeforeForkInParent() NO_THREAD_SAFETY_ANALYSIS {
       LockRoot, false,
       internal::PartitionRootEnumerator::EnumerateOrder::kNormal);
 
-  internal::ThreadCacheRegistry::GetLock().Acquire();
+  ThreadCacheRegistry::GetLock().Acquire();
 }
 
 template <typename T>
@@ -193,7 +190,7 @@ void UnlockOrReinitRoot(PartitionRoot<internal::ThreadSafe>* root,
 
 void ReleaseLocks(bool in_child) NO_THREAD_SAFETY_ANALYSIS {
   // In reverse order, even though there are no lock ordering dependencies.
-  UnlockOrReinit(internal::ThreadCacheRegistry::GetLock(), in_child);
+  UnlockOrReinit(ThreadCacheRegistry::GetLock(), in_child);
   internal::PartitionRootEnumerator::Instance().Enumerate(
       UnlockOrReinitRoot, in_child,
       internal::PartitionRootEnumerator::EnumerateOrder::kReverse);
@@ -217,8 +214,7 @@ void AfterForkInChild() {
   // If we don't reclaim this memory, it is lost forever. Note that this is only
   // really an issue if we fork() a multi-threaded process without calling
   // exec() right away, which is discouraged.
-  internal::ThreadCacheRegistry::Instance()
-      .ForcePurgeAllThreadAfterForkUnsafe();
+  ThreadCacheRegistry::Instance().ForcePurgeAllThreadAfterForkUnsafe();
 }
 #endif  // defined(PA_HAS_ATFORK_HANDLER)
 
@@ -309,15 +305,17 @@ static size_t PartitionPurgeSlotSpan(
   constexpr size_t kMaxSlotCount =
       (PartitionPageSize() * kMaxPartitionPagesPerRegularSlotSpan) /
       SystemPageSize();
-#elif BUILDFLAG(IS_APPLE)
+#elif BUILDFLAG(IS_APPLE) || (BUILDFLAG(IS_LINUX) && defined(ARCH_CPU_ARM64))
   // It's better for slot_usage to be stack-allocated and fixed-size, which
-  // demands that its size be constexpr. On OS_APPLE, PartitionPageSize() is
-  // always SystemPageSize() << 2, so regardless of what the run time page size
-  // is, kMaxSlotCount can always be simplified to this expression.
-  constexpr size_t kMaxSlotCount = 4 * kMaxPartitionPagesPerRegularSlotSpan;
-  PA_CHECK(kMaxSlotCount ==
-           (PartitionPageSize() * kMaxPartitionPagesPerRegularSlotSpan) /
-               SystemPageSize());
+  // demands that its size be constexpr. On IS_APPLE and Linux on arm64,
+  // PartitionPageSize() is always SystemPageSize() << 2, so regardless of
+  // what the run time page size is, kMaxSlotCount can always be simplified
+  // to this expression.
+  constexpr size_t kMaxSlotCount =
+      4 * internal::kMaxPartitionPagesPerRegularSlotSpan;
+  PA_CHECK(kMaxSlotCount == (PartitionPageSize() *
+                             internal::kMaxPartitionPagesPerRegularSlotSpan) /
+                                SystemPageSize());
 #endif
   PA_DCHECK(bucket_num_slots <= kMaxSlotCount);
   PA_DCHECK(slot_span->num_unprovisioned_slots < bucket_num_slots);
@@ -477,9 +475,11 @@ static void PartitionDumpSlotSpanStats(
 
   if (slot_span->CanStoreRawSize()) {
     stats_out->active_bytes += static_cast<uint32_t>(slot_span->GetRawSize());
+    stats_out->active_count += 1;
   } else {
     stats_out->active_bytes +=
         (slot_span->num_allocated_slots * stats_out->bucket_slot_size);
+    stats_out->active_count += slot_span->num_allocated_slots;
   }
 
   size_t slot_span_bytes_resident = RoundUpToSystemPage(
@@ -523,6 +523,7 @@ static void PartitionDumpBucketStats(
   size_t bucket_useful_storage = stats_out->bucket_slot_size * bucket_num_slots;
   stats_out->allocated_slot_span_size = bucket->get_bytes_per_span();
   stats_out->active_bytes = bucket->num_full_slot_spans * bucket_useful_storage;
+  stats_out->active_count = bucket->num_full_slot_spans * bucket_num_slots;
   stats_out->resident_bytes =
       bucket->num_full_slot_spans * stats_out->allocated_slot_span_size;
 
@@ -573,7 +574,7 @@ template <bool thread_safe>
 
   // Check whether this OOM is due to a lot of super pages that are allocated
   // but not committed, probably due to http://crbug.com/421387.
-  if (uncommitted_size > kReasonableSizeOfUnusedPages) {
+  if (uncommitted_size > internal::kReasonableSizeOfUnusedPages) {
     internal::PartitionOutOfMemoryWithLotsOfUncommitedPages(size);
   }
 
@@ -625,14 +626,39 @@ void PartitionRoot<thread_safe>::DecommitEmptySlotSpans() {
   PA_DCHECK(empty_slot_spans_dirty_bytes == 0);
 }
 
+template <bool thread_safe>
+void PartitionRoot<thread_safe>::DestructForTesting() {
+  // We need to destruct the thread cache before we unreserve any of the super
+  // pages below, which we currently are not doing. So, we should only call
+  // this function on PartitionRoots without a thread cache.
+  PA_CHECK(!with_thread_cache);
+  auto pool_handle = ChoosePool();
+  auto* curr = first_extent;
+  while (curr != nullptr) {
+    auto* next = curr->next;
+    internal::AddressPoolManager::GetInstance()->UnreserveAndDecommit(
+        pool_handle, reinterpret_cast<uintptr_t>(curr),
+        internal::kSuperPageSize * curr->number_of_consecutive_super_pages);
+    curr = next;
+  }
+}
+
 template <bool thread_safe>
 void PartitionRoot<thread_safe>::Init(PartitionOptions opts) {
   {
 #if BUILDFLAG(IS_APPLE)
     // Needed to statically bound page size, which is a runtime constant on
     // apple OSes.
-    PA_CHECK((SystemPageSize() == (size_t{1} << 12)) ||
-             (SystemPageSize() == (size_t{1} << 14)));
+    PA_CHECK((internal::SystemPageSize() == (size_t{1} << 12)) ||
+             (internal::SystemPageSize() == (size_t{1} << 14)));
+#elif BUILDFLAG(IS_LINUX) && defined(ARCH_CPU_ARM64)
+    // Check runtime pagesize. Though the code is currently the same, it is
+    // not merged with the IS_APPLE case above as a 1 << 16 case needs to be
+    // added here in the future, to allow 64 kiB pagesize. That is only
+    // supported on Linux on arm64, not on IS_APPLE, but not yet present here
+    // as the rest of the partition allocator does not currently support it.
+    PA_CHECK((internal::SystemPageSize() == (size_t{1} << 12)) ||
+             (internal::SystemPageSize() == (size_t{1} << 14)));
 #endif
 
     ::partition_alloc::internal::ScopedGuard guard{lock_};
@@ -716,17 +742,18 @@ void PartitionRoot<thread_safe>::Init(PartitionOptions opts) {
     // Set up the actual usable buckets first.
     constexpr internal::BucketIndexLookup lookup{};
     size_t bucket_index = 0;
-    while (lookup.bucket_sizes()[bucket_index] != kInvalidBucketSize) {
+    while (lookup.bucket_sizes()[bucket_index] !=
+           internal::kInvalidBucketSize) {
       buckets[bucket_index].Init(lookup.bucket_sizes()[bucket_index]);
       bucket_index++;
     }
-    PA_DCHECK(bucket_index < kNumBuckets);
+    PA_DCHECK(bucket_index < internal::kNumBuckets);
 
     // Remaining buckets are not usable, and not real.
-    for (size_t index = bucket_index; index < kNumBuckets; index++) {
+    for (size_t index = bucket_index; index < internal::kNumBuckets; index++) {
       // Cannot init with size 0 since it computes 1 / size, but make sure the
       // bucket is invalid.
-      buckets[index].Init(kInvalidBucketSize);
+      buckets[index].Init(internal::kInvalidBucketSize);
       buckets[index].active_slot_spans_head = nullptr;
       PA_DCHECK(!buckets[index].is_valid());
     }
@@ -735,12 +762,12 @@ void PartitionRoot<thread_safe>::Init(PartitionOptions opts) {
     // TLS in ThreadCache not supported on other OSes.
     with_thread_cache = false;
 #else
-    internal::ThreadCache::EnsureThreadSpecificDataInitialized();
+    ThreadCache::EnsureThreadSpecificDataInitialized();
     with_thread_cache =
         (opts.thread_cache == PartitionOptions::ThreadCache::kEnabled);
 
     if (with_thread_cache)
-      internal::ThreadCache::Init(this);
+      ThreadCache::Init(this);
 #endif  // !defined(PA_THREAD_CACHE_SUPPORTED)
 
 #if defined(PA_USE_PARTITION_ROOT_ENUMERATOR)
@@ -786,7 +813,7 @@ void PartitionRoot<thread_safe>::EnableThreadCacheIfSupported() {
   int before =
       thread_caches_being_constructed_.fetch_add(1, std::memory_order_acquire);
   PA_CHECK(before == 0);
-  internal::ThreadCache::Init(this);
+  ThreadCache::Init(this);
   thread_caches_being_constructed_.fetch_sub(1, std::memory_order_release);
   with_thread_cache = true;
 #endif  // defined(PA_THREAD_CACHE_SUPPORTED)
@@ -817,15 +844,15 @@ bool PartitionRoot<thread_safe>::TryReallocInPlaceForDirectMap(
   // Make this check before comparing slot sizes, as even with equal or similar
   // slot sizes we can save a lot if the original allocation was heavily padded
   // for alignment.
-  if ((new_reservation_size >> SystemPageShift()) * 5 <
-      (current_reservation_size >> SystemPageShift()) * 4)
+  if ((new_reservation_size >> internal::SystemPageShift()) * 5 <
+      (current_reservation_size >> internal::SystemPageShift()) * 4)
     return false;
 
   // Note that the new size isn't a bucketed size; this function is called
   // whenever we're reallocating a direct mapped allocation, so calculate it
   // the way PartitionDirectMap() would.
   size_t new_slot_size = GetDirectMapSlotSize(raw_size);
-  if (new_slot_size < kMinDirectMappedDownsize)
+  if (new_slot_size < internal::kMinDirectMappedDownsize)
     return false;
 
   // Past this point, we decided we'll attempt to reallocate without relocating,
@@ -841,11 +868,12 @@ bool PartitionRoot<thread_safe>::TryReallocInPlaceForDirectMap(
       current_reservation_size - extent->padding_for_alignment -
       PartitionRoot<thread_safe>::GetDirectMapMetadataAndGuardPagesSize();
 #if DCHECK_IS_ON()
-  uintptr_t reservation_start = slot_start & kSuperPageBaseMask;
+  uintptr_t reservation_start = slot_start & internal::kSuperPageBaseMask;
   PA_DCHECK(internal::IsReservationStart(reservation_start));
   PA_DCHECK(slot_start + available_reservation_size ==
             reservation_start + current_reservation_size -
-                GetDirectMapMetadataAndGuardPagesSize() + PartitionPageSize());
+                GetDirectMapMetadataAndGuardPagesSize() +
+                internal::PartitionPageSize());
 #endif
 
   if (new_slot_size == current_slot_size) {
@@ -871,7 +899,7 @@ bool PartitionRoot<thread_safe>::TryReallocInPlaceForDirectMap(
 
 #if DCHECK_IS_ON()
     memset(reinterpret_cast<void*>(slot_start + current_slot_size),
-           kUninitializedByte, recommit_slot_size_growth);
+           internal::kUninitializedByte, recommit_slot_size_growth);
 #endif
   } else {
     // We can't perform the realloc in-place.
@@ -961,9 +989,10 @@ void* PartitionRoot<thread_safe>::ReallocWithFlags(int flags,
   bool no_hooks = flags & AllocFlags::kNoHooks;
   if (UNLIKELY(!ptr)) {
     return no_hooks
-               ? AllocWithFlagsNoHooks(flags, new_size, PartitionPageSize())
-               : AllocWithFlagsInternal(flags, new_size, PartitionPageSize(),
-                                        type_name);
+               ? AllocWithFlagsNoHooks(flags, new_size,
+                                       internal::PartitionPageSize())
+               : AllocWithFlagsInternal(
+                     flags, new_size, internal::PartitionPageSize(), type_name);
   }
 
   if (UNLIKELY(!new_size)) {
@@ -971,7 +1000,7 @@ void* PartitionRoot<thread_safe>::ReallocWithFlags(int flags,
     return nullptr;
   }
 
-  if (new_size > MaxDirectMapped()) {
+  if (new_size > internal::MaxDirectMapped()) {
     if (flags & AllocFlags::kReturnNull)
       return nullptr;
     internal::PartitionExcessiveAllocationSize(new_size);
@@ -1019,10 +1048,11 @@ void* PartitionRoot<thread_safe>::ReallocWithFlags(int flags,
   }
 
   // This realloc cannot be resized in-place. Sadness.
-  void* ret = no_hooks
-                  ? AllocWithFlagsNoHooks(flags, new_size, PartitionPageSize())
-                  : AllocWithFlagsInternal(flags, new_size, PartitionPageSize(),
-                                           type_name);
+  void* ret =
+      no_hooks ? AllocWithFlagsNoHooks(flags, new_size,
+                                       internal::PartitionPageSize())
+               : AllocWithFlagsInternal(
+                     flags, new_size, internal::PartitionPageSize(), type_name);
   if (!ret) {
     if (flags & AllocFlags::kReturnNull)
       return nullptr;
@@ -1050,10 +1080,10 @@ void PartitionRoot<thread_safe>::PurgeMemory(int flags) {
       DecommitEmptySlotSpans();
     if (flags & PurgeFlags::kDiscardUnusedSystemPages) {
       for (Bucket& bucket : buckets) {
-        if (bucket.slot_size == kInvalidBucketSize)
+        if (bucket.slot_size == internal::kInvalidBucketSize)
           continue;
 
-        if (bucket.slot_size >= SystemPageSize())
+        if (bucket.slot_size >= internal::SystemPageSize())
           internal::PartitionPurgeBucket(&bucket);
         else
           bucket.SortSlotSpanFreelists();
@@ -1082,7 +1112,7 @@ void PartitionRoot<thread_safe>::ShrinkEmptySlotSpansRing(size_t limit) {
     // are unused, if global_empty_slot_span_ring_size is smaller than
     // kMaxFreeableSpans. It's simpler, and does not cost anything, since all
     // the pointers are going to be nullptr.
-    if (index == kMaxFreeableSpans)
+    if (index == internal::kMaxFreeableSpans)
       index = 0;
 
     // Went around the whole ring, since this is locked,
@@ -1109,7 +1139,7 @@ void PartitionRoot<thread_safe>::DumpStats(const char* partition_name,
     direct_map_lengths =
         std::unique_ptr<uint32_t[]>(new uint32_t[kMaxReportableDirectMaps]);
   }
-  PartitionBucketMemoryStats bucket_stats[kNumBuckets];
+  PartitionBucketMemoryStats bucket_stats[internal::kNumBuckets];
   size_t num_direct_mapped_allocations = 0;
   PartitionMemoryStats stats = {0};
 
@@ -1140,7 +1170,7 @@ void PartitionRoot<thread_safe>::DumpStats(const char* partition_name,
 #endif
 
     size_t direct_mapped_allocations_total_size = 0;
-    for (size_t i = 0; i < kNumBuckets; ++i) {
+    for (size_t i = 0; i < internal::kNumBuckets; ++i) {
       const Bucket* bucket = &bucket_at(i);
       // Don't report the pseudo buckets that the generic allocator sets up in
       // order to preserve a fast size->bucket map (see
@@ -1152,6 +1182,7 @@ void PartitionRoot<thread_safe>::DumpStats(const char* partition_name,
       if (bucket_stats[i].is_valid) {
         stats.total_resident_bytes += bucket_stats[i].resident_bytes;
         stats.total_active_bytes += bucket_stats[i].active_bytes;
+        stats.total_active_count += bucket_stats[i].active_count;
         stats.total_decommittable_bytes += bucket_stats[i].decommittable_bytes;
         stats.total_discardable_bytes += bucket_stats[i].discardable_bytes;
       }
@@ -1171,13 +1202,14 @@ void PartitionRoot<thread_safe>::DumpStats(const char* partition_name,
 
     stats.total_resident_bytes += direct_mapped_allocations_total_size;
     stats.total_active_bytes += direct_mapped_allocations_total_size;
+    stats.total_active_count += num_direct_mapped_allocations;
 
     stats.has_thread_cache = with_thread_cache;
     if (stats.has_thread_cache) {
-      internal::ThreadCacheRegistry::Instance().DumpStats(
+      ThreadCacheRegistry::Instance().DumpStats(
           true, &stats.current_thread_cache_stats);
-      internal::ThreadCacheRegistry::Instance().DumpStats(
-          false, &stats.all_thread_caches_stats);
+      ThreadCacheRegistry::Instance().DumpStats(false,
+                                                &stats.all_thread_caches_stats);
     }
   }
 
@@ -1198,6 +1230,7 @@ void PartitionRoot<thread_safe>::DumpStats(const char* partition_name,
       mapped_stats.allocated_slot_span_size = size;
       mapped_stats.bucket_slot_size = size;
       mapped_stats.active_bytes = size;
+      mapped_stats.active_count = 1;
       mapped_stats.resident_bytes = size;
       dumper->PartitionsDumpBucketStats(partition_name, &mapped_stats);
     }
@@ -1209,7 +1242,7 @@ template <bool thread_safe>
 void PartitionRoot<thread_safe>::DeleteForTesting(
     PartitionRoot* partition_root) {
   if (partition_root->with_thread_cache) {
-    internal::ThreadCache::SwapForTesting(nullptr);
+    ThreadCache::SwapForTesting(nullptr);
     partition_root->with_thread_cache = false;
   }
 
@@ -1227,10 +1260,10 @@ template <>
 uintptr_t PartitionRoot<internal::ThreadSafe>::MaybeInitThreadCacheAndAlloc(
     uint16_t bucket_index,
     size_t* slot_size) {
-  auto* tcache = internal::ThreadCache::Get();
+  auto* tcache = ThreadCache::Get();
   // See comment in `EnableThreadCacheIfSupport()` for why this is an acquire
   // load.
-  if (internal::ThreadCache::IsTombstone(tcache) ||
+  if (ThreadCache::IsTombstone(tcache) ||
       thread_caches_being_constructed_.load(std::memory_order_acquire)) {
     // Two cases:
     // 1. Thread is being terminated, don't try to use the thread cache, and
@@ -1259,7 +1292,7 @@ uintptr_t PartitionRoot<internal::ThreadSafe>::MaybeInitThreadCacheAndAlloc(
   int before =
       thread_caches_being_constructed_.fetch_add(1, std::memory_order_relaxed);
   PA_CHECK(before < std::numeric_limits<int>::max());
-  tcache = internal::ThreadCache::Create(this);
+  tcache = ThreadCache::Create(this);
   thread_caches_being_constructed_.fetch_sub(1, std::memory_order_relaxed);
 
   // Cache is created empty, but at least this will trigger batch fill, which
@@ -1272,11 +1305,11 @@ template struct BASE_EXPORT PartitionRoot<internal::ThreadSafe>;
 
 static_assert(offsetof(PartitionRoot<internal::ThreadSafe>, sentinel_bucket) ==
                   offsetof(PartitionRoot<internal::ThreadSafe>, buckets) +
-                      kNumBuckets *
+                      internal::kNumBuckets *
                           sizeof(PartitionRoot<internal::ThreadSafe>::Bucket),
               "sentinel_bucket must be just after the regular buckets.");
 
 static_assert(
     offsetof(PartitionRoot<internal::ThreadSafe>, lock_) >= 64,
     "The lock should not be on the same cacheline as the read-mostly flags");
-}  // namespace base
+}  // namespace partition_alloc
