@@ -6,10 +6,9 @@
 
 #include <cstring>
 
-#include "base/no_destructor.h"
+#include "base/allocator/partition_allocator/partition_alloc_base/no_destructor.h"
 
-namespace base {
-namespace internal {
+namespace partition_alloc::internal {
 
 namespace {
 constexpr PartitionOptions kConfig{
@@ -23,7 +22,8 @@ constexpr PartitionOptions kConfig{
 }  // namespace
 
 ThreadSafePartitionRoot& PCScanMetadataAllocator() {
-  static base::NoDestructor<ThreadSafePartitionRoot> allocator(kConfig);
+  static internal::base::NoDestructor<ThreadSafePartitionRoot> allocator(
+      kConfig);
   return *allocator;
 }
 
@@ -37,5 +37,4 @@ void ReinitPCScanMetadataAllocatorForTesting() {
   PCScanMetadataAllocator().Init(kConfig);
 }
 
-}  // namespace internal
-}  // namespace base
+}  // namespace partition_alloc::internal
