@@ -11,6 +11,7 @@
 #include "base/check.h"
 #include "base/feature_list.h"
 #include "base/memory/ptr_util.h"
+#include "base/memory/raw_ptr_exclusion.h"
 #include "base/memory/ref_counted.h"
 #include "base/threading/platform_thread.h"
 #include "base/threading/sequenced_task_runner_handle.h"
@@ -28,41 +29,21 @@ namespace {
 constexpr Feature kAlwaysAbandonScheduledTask{"AlwaysAbandonScheduledTask",
                                               FEATURE_DISABLED_BY_DEFAULT};
 
+// Cache of the state of the kAlwaysAbandonScheduledTask feature. This avoids
+// the need to constantly query its enabled state through
+// FeatureList::IsEnabled().
+bool g_is_always_abandon_scheduled_task_enabled =
+    kAlwaysAbandonScheduledTask.default_state == FEATURE_ENABLED_BY_DEFAULT;
+
 }  // namespace
 
-// TaskDestructionDetector's role is to detect when the scheduled task is
-// deleted without being executed. It can be disabled when the timer no longer
-// wants to be notified.
-class TaskDestructionDetector {
- public:
-  explicit TaskDestructionDetector(TimerBase* timer) : timer_(timer) {}
+// static
+void TimerBase::InitializeFeatures() {
+  g_is_always_abandon_scheduled_task_enabled =
+      FeatureList::IsEnabled(kAlwaysAbandonScheduledTask);
+}
 
-  TaskDestructionDetector(const TaskDestructionDetector&) = delete;
-  TaskDestructionDetector& operator=(const TaskDestructionDetector&) = delete;
-
-  ~TaskDestructionDetector() {
-    // If this instance is getting destroyed before it was disabled, notify the
-    // timer.
-    if (timer_)
-      timer_->OnTaskDestroyed();
-  }
-
-  // Disables this instance so that the timer is no longer notified in the
-  // destructor.
-  void Disable() { timer_ = nullptr; }
-
- private:
-  // `timer_` is not a raw_ptr<...> for performance reasons (based on analysis
-  // of sampling profiler data and tab_search:top100:2020).
-  TimerBase* timer_;
-};
-
-TimerBase::TimerBase() : TimerBase(nullptr) {}
-
-TimerBase::TimerBase(const TickClock* tick_clock)
-    : task_destruction_detector_(nullptr),
-      tick_clock_(tick_clock),
-      is_running_(false) {
+TimerBase::TimerBase(const Location& posted_from) : posted_from_(posted_from) {
   // It is safe for the timer to be created on a different thread/sequence than
   // the one from which the timer APIs are called. The first call to the
   // checker's CalledOnValidSequence() method will re-bind the checker, and
@@ -70,21 +51,6 @@ TimerBase::TimerBase(const TickClock* tick_clock)
   DETACH_FROM_SEQUENCE(sequence_checker_);
 }
 
-TimerBase::TimerBase(const Location& posted_from, TimeDelta delay)
-    : TimerBase(posted_from, delay, nullptr) {}
-
-TimerBase::TimerBase(const Location& posted_from,
-                     TimeDelta delay,
-                     const TickClock* tick_clock)
-    : task_destruction_detector_(nullptr),
-      posted_from_(posted_from),
-      delay_(delay),
-      tick_clock_(tick_clock),
-      is_running_(false) {
-  // See comment in other constructor.
-  DETACH_FROM_SEQUENCE(sequence_checker_);
-}
-
 TimerBase::~TimerBase() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   AbandonScheduledTask();
@@ -92,12 +58,20 @@ TimerBase::~TimerBase() {
 
 bool TimerBase::IsRunning() const {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-  return is_running_;
-}
 
-TimeDelta TimerBase::GetCurrentDelay() const {
-  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-  return delay_;
+  // When the `kAlwaysAbandonScheduledTask` feature is enabled, checking
+  // `delayed_task_handle_.IsValid()` is sufficient to determine if the
+  // timer is running. When the feature is disabled, the delayed task
+  // is not abandoned when the timer is stopped and the handle remains
+  // valid, so it's necessary to also check `is_running_` (set to false
+  // from `Stop()`).
+  //
+  // TODO(crbug.com/1262205): Remove the `is_running_` check once the
+  // "AlwaysAbandonScheduledTask" feature is launched.
+  if (!is_running_)
+    return false;
+
+  return delayed_task_handle_.IsValid();
 }
 
 void TimerBase::SetTaskRunner(scoped_refptr<SequencedTaskRunner> task_runner) {
@@ -107,7 +81,48 @@ void TimerBase::SetTaskRunner(scoped_refptr<SequencedTaskRunner> task_runner) {
   task_runner_.swap(task_runner);
 }
 
-void TimerBase::StartInternal(const Location& posted_from, TimeDelta delay) {
+scoped_refptr<SequencedTaskRunner> TimerBase::GetTaskRunner() {
+  return task_runner_ ? task_runner_ : SequencedTaskRunnerHandle::Get();
+}
+
+void TimerBase::Stop() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+
+  is_running_ = false;
+  AbandonScheduledTask();
+
+  OnStop();
+  // No more member accesses here: |this| could be deleted after Stop() call.
+}
+
+void TimerBase::AbandonScheduledTask() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+
+  if (delayed_task_handle_.IsValid())
+    delayed_task_handle_.CancelTask();
+
+  // It's safe to destroy or restart Timer on another sequence after the task is
+  // abandoned.
+  DETACH_FROM_SEQUENCE(sequence_checker_);
+}
+
+DelayTimerBase::DelayTimerBase(const TickClock* tick_clock)
+    : tick_clock_(tick_clock) {}
+
+DelayTimerBase::DelayTimerBase(const Location& posted_from,
+                               TimeDelta delay,
+                               const TickClock* tick_clock)
+    : TimerBase(posted_from), delay_(delay), tick_clock_(tick_clock) {}
+
+DelayTimerBase::~DelayTimerBase() = default;
+
+TimeDelta DelayTimerBase::GetCurrentDelay() const {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  return delay_;
+}
+
+void DelayTimerBase::StartInternal(const Location& posted_from,
+                                   TimeDelta delay) {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
 
   posted_from_ = posted_from;
@@ -116,44 +131,28 @@ void TimerBase::StartInternal(const Location& posted_from, TimeDelta delay) {
   Reset();
 }
 
-void TimerBase::OnTaskDestroyed() {
-  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-
-  DCHECK(task_destruction_detector_);
-  task_destruction_detector_ = nullptr;
-
-  delayed_task_handle_.CancelTask();
-  is_running_ = false;
-
-  // It's safe to destroy or restart Timer on another sequence after it has been
-  // stopped.
-  DETACH_FROM_SEQUENCE(sequence_checker_);
-
-  OnStop();
-  // No more member accesses here: |this| could be deleted after OnStop() call.
-}
-
-void TimerBase::Stop() {
+void DelayTimerBase::AbandonAndStop() {
+  // Note: Stop() is more or less re-implemented here because it cannot be
+  // called without rebinding the |sequence_checker_| to the current sequence
+  // after the call to AbandonScheduledTask().
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
 
   is_running_ = false;
 
-  if (FeatureList::IsEnabled(kAlwaysAbandonScheduledTask))
-    AbandonScheduledTask();
-
-  // It's safe to destroy or restart Timer on another sequence after Stop().
-  DETACH_FROM_SEQUENCE(sequence_checker_);
+  AbandonScheduledTask();
 
   OnStop();
-  // No more member accesses here: |this| could be deleted after Stop() call.
+  // No more member accesses here: |this| could be deleted at this point.
 }
 
-void TimerBase::Reset() {
+void DelayTimerBase::Reset() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
 
-  if (!FeatureList::IsEnabled(kAlwaysAbandonScheduledTask)) {
+  EnsureNonNullUserTask();
+
+  if (!g_is_always_abandon_scheduled_task_enabled) {
     // If there's no pending task, start one up and return.
-    if (!task_destruction_detector_) {
+    if (!delayed_task_handle_.IsValid()) {
       ScheduleNewTask(delay_);
       return;
     }
@@ -177,13 +176,23 @@ void TimerBase::Reset() {
   ScheduleNewTask(delay_);
 }
 
-void TimerBase::ScheduleNewTask(TimeDelta delay) {
+// TODO(1262205): Merge with TimerBase::Stop() once the "always abandon
+// scheduled task" feature is launched.
+void DelayTimerBase::Stop() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-  DCHECK(!task_destruction_detector_);
+
+  is_running_ = false;
+  if (g_is_always_abandon_scheduled_task_enabled)
+    AbandonScheduledTask();
+
+  OnStop();
+  // No more member accesses here: |this| could be deleted after Stop() call.
+}
+
+void DelayTimerBase::ScheduleNewTask(TimeDelta delay) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  DCHECK(!delayed_task_handle_.IsValid());
   is_running_ = true;
-  auto task_destruction_detector =
-      std::make_unique<TaskDestructionDetector>(this);
-  task_destruction_detector_ = task_destruction_detector.get();
 
   // Ignore negative deltas.
   // TODO(pmonette): Fix callers providing negative deltas and ban passing them.
@@ -191,50 +200,24 @@ void TimerBase::ScheduleNewTask(TimeDelta delay) {
     delay = TimeDelta();
 
   delayed_task_handle_ = GetTaskRunner()->PostCancelableDelayedTask(
-      posted_from_,
-      BindOnce(&TimerBase::OnScheduledTaskInvoked, Unretained(this),
-               std::move(task_destruction_detector)),
+      base::subtle::PostDelayedTaskPassKey(), posted_from_,
+      BindOnce(&DelayTimerBase::OnScheduledTaskInvoked, Unretained(this)),
       delay);
   scheduled_run_time_ = desired_run_time_ = Now() + delay;
 }
 
-scoped_refptr<SequencedTaskRunner> TimerBase::GetTaskRunner() {
-  return task_runner_.get() ? task_runner_ : SequencedTaskRunnerHandle::Get();
-}
-
-TimeTicks TimerBase::Now() const {
+TimeTicks DelayTimerBase::Now() const {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   return tick_clock_ ? tick_clock_->NowTicks() : TimeTicks::Now();
 }
 
-void TimerBase::AbandonScheduledTask() {
+void DelayTimerBase::OnScheduledTaskInvoked() {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-
-  if (task_destruction_detector_) {
-    task_destruction_detector_->Disable();
-    task_destruction_detector_ = nullptr;
-
-    DCHECK(delayed_task_handle_.IsValid());
-    delayed_task_handle_.CancelTask();
-  }
-}
-
-void TimerBase::OnScheduledTaskInvoked(
-    std::unique_ptr<TaskDestructionDetector> task_destruction_detector) {
-  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
-  DCHECK(!delayed_task_handle_.IsValid());
-
-  // The scheduled task is currently running so its destruction detector is no
-  // longer needed.
-  task_destruction_detector->Disable();
-  task_destruction_detector_ = nullptr;
-  task_destruction_detector.reset();
+  DCHECK(!delayed_task_handle_.IsValid()) << posted_from_.ToString();
 
   // The timer may have been stopped.
-  if (!is_running_) {
-    DCHECK(!FeatureList::IsEnabled(kAlwaysAbandonScheduledTask));
+  if (!is_running_)
     return;
-  }
 
   // First check if we need to delay the task because of a new target time.
   if (desired_run_time_ > scheduled_run_time_) {
@@ -244,7 +227,6 @@ void TimerBase::OnScheduledTaskInvoked(
     // Task runner may have called us late anyway, so only post a continuation
     // task if the |desired_run_time_| is in the future.
     if (desired_run_time_ > now) {
-      DCHECK(!FeatureList::IsEnabled(kAlwaysAbandonScheduledTask));
       // Post a new task to span the remaining time.
       ScheduleNewTask(desired_run_time_ - now);
       return;
@@ -259,7 +241,7 @@ void TimerBase::OnScheduledTaskInvoked(
 
 OneShotTimer::OneShotTimer() = default;
 OneShotTimer::OneShotTimer(const TickClock* tick_clock)
-    : internal::TimerBase(tick_clock) {}
+    : internal::DelayTimerBase(tick_clock) {}
 OneShotTimer::~OneShotTimer() = default;
 
 void OneShotTimer::Start(const Location& posted_from,
@@ -293,21 +275,25 @@ void OneShotTimer::RunUserTask() {
   // No more member accesses here: |this| could be deleted at this point.
 }
 
+void OneShotTimer::EnsureNonNullUserTask() {
+  DCHECK(user_task_);
+}
+
 RepeatingTimer::RepeatingTimer() = default;
 RepeatingTimer::RepeatingTimer(const TickClock* tick_clock)
-    : internal::TimerBase(tick_clock) {}
+    : internal::DelayTimerBase(tick_clock) {}
 RepeatingTimer::~RepeatingTimer() = default;
 
 RepeatingTimer::RepeatingTimer(const Location& posted_from,
                                TimeDelta delay,
                                RepeatingClosure user_task)
-    : internal::TimerBase(posted_from, delay),
+    : internal::DelayTimerBase(posted_from, delay),
       user_task_(std::move(user_task)) {}
 RepeatingTimer::RepeatingTimer(const Location& posted_from,
                                TimeDelta delay,
                                RepeatingClosure user_task,
                                const TickClock* tick_clock)
-    : internal::TimerBase(posted_from, delay, tick_clock),
+    : internal::DelayTimerBase(posted_from, delay, tick_clock),
       user_task_(std::move(user_task)) {}
 
 void RepeatingTimer::Start(const Location& posted_from,
@@ -327,21 +313,25 @@ void RepeatingTimer::RunUserTask() {
   // No more member accesses here: |this| could be deleted at this point.
 }
 
+void RepeatingTimer::EnsureNonNullUserTask() {
+  DCHECK(user_task_);
+}
+
 RetainingOneShotTimer::RetainingOneShotTimer() = default;
 RetainingOneShotTimer::RetainingOneShotTimer(const TickClock* tick_clock)
-    : internal::TimerBase(tick_clock) {}
+    : internal::DelayTimerBase(tick_clock) {}
 RetainingOneShotTimer::~RetainingOneShotTimer() = default;
 
 RetainingOneShotTimer::RetainingOneShotTimer(const Location& posted_from,
                                              TimeDelta delay,
                                              RepeatingClosure user_task)
-    : internal::TimerBase(posted_from, delay),
+    : internal::DelayTimerBase(posted_from, delay),
       user_task_(std::move(user_task)) {}
 RetainingOneShotTimer::RetainingOneShotTimer(const Location& posted_from,
                                              TimeDelta delay,
                                              RepeatingClosure user_task,
                                              const TickClock* tick_clock)
-    : internal::TimerBase(posted_from, delay, tick_clock),
+    : internal::DelayTimerBase(posted_from, delay, tick_clock),
       user_task_(std::move(user_task)) {}
 
 void RetainingOneShotTimer::Start(const Location& posted_from,
@@ -361,4 +351,55 @@ void RetainingOneShotTimer::RunUserTask() {
   // No more member accesses here: |this| could be deleted at this point.
 }
 
+void RetainingOneShotTimer::EnsureNonNullUserTask() {
+  DCHECK(user_task_);
+}
+
+DeadlineTimer::DeadlineTimer() = default;
+DeadlineTimer::~DeadlineTimer() = default;
+
+void DeadlineTimer::Start(const Location& posted_from,
+                          TimeTicks deadline,
+                          OnceClosure user_task,
+                          ExactDeadline exact) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  DCHECK(!delayed_task_handle_.IsValid());
+  user_task_ = std::move(user_task);
+  posted_from_ = posted_from;
+  subtle::DelayPolicy delay_policy =
+      exact ? subtle::DelayPolicy::kPrecise
+            : subtle::DelayPolicy::kFlexiblePreferEarly;
+
+  ScheduleNewTask(deadline, delay_policy);
+}
+
+void DeadlineTimer::OnStop() {
+  user_task_.Reset();
+  // No more member accesses here: |this| could be deleted after freeing
+  // |user_task_|.
+}
+
+void DeadlineTimer::ScheduleNewTask(TimeTicks deadline,
+                                    subtle::DelayPolicy delay_policy) {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  is_running_ = true;
+
+  delayed_task_handle_ = GetTaskRunner()->PostCancelableDelayedTaskAt(
+      base::subtle::PostDelayedTaskPassKey(), posted_from_,
+      BindOnce(&DeadlineTimer::OnScheduledTaskInvoked, Unretained(this)),
+      deadline, delay_policy);
+}
+
+void DeadlineTimer::OnScheduledTaskInvoked() {
+  DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
+  DCHECK(!delayed_task_handle_.IsValid());
+
+  // Make a local copy of the task to run. The Stop method will reset the
+  // |user_task_| member.
+  OnceClosure task = std::move(user_task_);
+  Stop();
+  std::move(task).Run();
+  // No more member accesses here: |this| could be deleted at this point.
+}
+
 }  // namespace base
