@@ -11,6 +11,7 @@
 
 #include "base/allocator/buildflags.h"
 #include "base/strings/string_util.h"
+#include "build/build_config.h"
 
 namespace base {
 namespace trace_event {
@@ -44,6 +45,9 @@ const char* const kDumpProviderAllowlist[] = {
     "GrShaderCache",
     "FontCaches",
     "HistoryReport",
+#if BUILDFLAG(IS_MAC)
+    "CommandBuffer",
+#endif
     "IPCChannel",
     "IndexedDBBackingStore",
     "IndexedDBFactoryImpl",
@@ -134,6 +138,9 @@ const char* const kAllocatorDumpNameAllowlist[] = {
     "gpu/transfer_cache/cache_0x?/avg_image_size",
     "history/delta_file_service/leveldb_0x?",
     "history/usage_reports_buffer/leveldb_0x?",
+#if BUILDFLAG(IS_MAC)
+    "iosurface",
+#endif
     "java_heap",
     "java_heap/allocated_objects",
     "leveldatabase",
@@ -156,6 +163,7 @@ const char* const kAllocatorDumpNameAllowlist[] = {
     "malloc/partitions/original",
     "malloc/partitions/nonscannable",
     "malloc/partitions/nonquarantinable",
+    "malloc/sys_malloc",
     "malloc/win_heap",
 #endif
     "media/webmediaplayer/audio/player_0x?",
@@ -269,6 +277,7 @@ const char* const kAllocatorDumpNameAllowlist[] = {
     "sync/0x?/model_type/DICTIONARY",
     "sync/0x?/model_type/EXTENSION",
     "sync/0x?/model_type/EXTENSION_SETTING",
+    "sync/0x?/model_type/HISTORY",
     "sync/0x?/model_type/HISTORY_DELETE_DIRECTIVE",
     "sync/0x?/model_type/MANAGED_USER",
     "sync/0x?/model_type/MANAGED_USER_SETTING",
