@@ -139,9 +139,9 @@ class ListValue;
 //
 // Lists support:
 // - `empty()`, `size()`, `begin()`, `end()`, `cbegin()`, `cend()`,
-//       `operator[]`, `clear()`, `erase()`: Identical to the STL container
-//       equivalents, with additional safety checks, e.g. `operator[]` will
-//       `CHECK()` if the index is out of range.
+//       `front()`, `back()`, `reserve()`, `operator[]`, `clear()`, `erase()`:
+//       Identical to the STL container equivalents, with additional safety
+//       checks, e.g. `operator[]` will `CHECK()` if the index is out of range.
 // - `Clone()`: Create a deep copy.
 // - `Append()`: Append a value to the end of the list. Accepts `Value` or any
 //       of the subtypes that `Value` can hold.
@@ -171,7 +171,7 @@ class ListValue;
 //
 //   base::Value GetFoo() {
 //     base::Value::Dict dict;
-//     dict.SetString("mykey", "abc");
+//     dict.Set("mykey", "abc");
 //     return base::Value(std::move(dict));
 //   }
 //
@@ -518,6 +518,9 @@ class BASE_EXPORT GSL_OWNER Value {
 
     absl::optional<Value> ExtractByDottedPath(StringPiece path);
 
+    // Serializes to a string for logging and debug purposes.
+    std::string DebugString() const;
+
    private:
     BASE_EXPORT friend bool operator==(const Dict& lhs, const Dict& rhs);
     BASE_EXPORT friend bool operator!=(const Dict& lhs, const Dict& rhs);
@@ -571,6 +574,20 @@ class BASE_EXPORT GSL_OWNER Value {
     const_iterator end() const;
     const_iterator cend() const;
 
+    // Returns a reference to the first value in the container. Fails with
+    // `CHECK()` if the list is empty.
+    const Value& front() const;
+    Value& front();
+
+    // Returns a reference to the last value in the container. Fails with
+    // `CHECK()` if the list is empty.
+    const Value& back() const;
+    Value& back();
+
+    // Increase the capacity of the backing container, but does not change
+    // the size. Assume all existing iterators will be invalidated.
+    void reserve(size_t capacity);
+
     // Returns a reference to the value at `index` in this list. Fails with a
     // `CHECK()` if `index >= size()`.
     const Value& operator[](size_t index) const;
@@ -579,8 +596,8 @@ class BASE_EXPORT GSL_OWNER Value {
     // Removes all value from this list.
     void clear();
 
-    // Removes the value referenced by `pos` in this listand returns an iterator
-    // to the value following the removed value.
+    // Removes the value referenced by `pos` in this list and returns an
+    // iterator to the value following the removed value.
     iterator erase(iterator pos);
     const_iterator erase(const_iterator pos);
 
@@ -618,6 +635,9 @@ class BASE_EXPORT GSL_OWNER Value {
       return base::EraseIf(storage_, predicate);
     }
 
+    // Serializes to a string for logging and debug purposes.
+    std::string DebugString() const;
+
    private:
     BASE_EXPORT friend bool operator==(const List& lhs, const List& rhs);
     BASE_EXPORT friend bool operator!=(const List& lhs, const List& rhs);
@@ -1096,7 +1116,7 @@ class BASE_EXPORT GSL_OWNER Value {
     //       SomeFunction(member);
     //     }
     //   });
-    operator double() const { return bit_cast<double>(v_); }
+    operator double() const { return base::bit_cast<double>(v_); }
 
    private:
     friend bool operator==(const DoubleStorage& lhs, const DoubleStorage& rhs) {
@@ -1130,8 +1150,6 @@ class BASE_EXPORT GSL_OWNER Value {
   explicit Value(absl::monostate);
   explicit Value(DoubleStorage storage);
 
-  friend class ValuesTest_SizeOfValue_Test;
-
   absl::variant<absl::monostate,
                 bool,
                 int,
@@ -1332,6 +1350,11 @@ class BASE_EXPORT ListValue : public Value {
   using Value::Append;
   // DEPRECATED: prefer `Value::List::Append()`.
   void Append(std::unique_ptr<Value> in_value);
+  // DEPRECATED: prefer `Value::List::Append()`. Provided to simplify
+  // incremental migration and intentionally only defined on ListValue and not
+  // Value.
+  void Append(base::Value::Dict in_dict);
+  void Append(base::Value::List in_list);
 
   // Swaps contents with the `other` list.
   //
