@@ -5,6 +5,7 @@
 #include "components/cronet/url_request_context_config.h"
 
 #include <memory>
+#include <type_traits>
 #include <utility>
 
 #include "base/json/json_reader.h"
@@ -100,6 +101,8 @@ const char kInitialDelayForBrokenAlternativeServiceSeconds[] =
     "initial_delay_for_broken_alternative_service_seconds";
 const char kExponentialBackoffOnInitialDelay[] =
     "exponential_backoff_on_initial_delay";
+const char kDelayMainJobWithAvailableSpdySession[] =
+    "delay_main_job_with_available_spdy_session";
 
 // AsyncDNS experiment dictionary name.
 const char kAsyncDnsFieldTrialName[] = "AsyncDNS";
@@ -235,8 +238,8 @@ ParseNetworkErrorLoggingHeaders(
 template <typename T, typename F>
 auto map(absl::optional<T> maybe, F&& f) {
   if (!maybe)
-    return absl::optional<base::invoke_result_t<F, T>>();
-  return absl::optional<base::invoke_result_t<F, T>>(f(maybe.value()));
+    return absl::optional<std::invoke_result_t<F, T>>();
+  return absl::optional<std::invoke_result_t<F, T>>(f(maybe.value()));
 }
 
 }  // namespace
@@ -588,6 +591,11 @@ void URLRequestContextConfig::SetContextBuilderExperimentalOptions(
       quic_params->exponential_backoff_on_initial_delay =
           quic_args.FindBoolKey(kExponentialBackoffOnInitialDelay);
 
+      quic_params->delay_main_job_with_available_spdy_session =
+          quic_args.FindBoolKey(kDelayMainJobWithAvailableSpdySession)
+              .value_or(
+                  quic_params->delay_main_job_with_available_spdy_session);
+
       quic_params->disable_tls_zero_rtt =
           quic_args.FindBoolKey(kDisableTlsZeroRtt)
               .value_or(quic_params->disable_tls_zero_rtt);
