@@ -9,6 +9,7 @@
 
 #include "base/callback_forward.h"
 #include "base/compiler_specific.h"
+#include "base/files/file_path.h"
 #include "build/chromeos_buildflags.h"
 #include "crypto/crypto_export.h"
 
@@ -56,7 +57,20 @@ CRYPTO_EXPORT void InitializeTPMTokenAndSystemSlot(
 // those methods. If neither of those methods have been called, this signals
 // that no TPM system slot will be available.
 CRYPTO_EXPORT void FinishInitializingTPMTokenAndSystemSlot();
-#endif
+
+// TODO(crbug.com/1163303) Remove when the bug is fixed.
+// Can be used to collect additional information when public slot fails to open.
+// Mainly checks the access permissions on the files and tries to read them.
+// Crashes Chrome because it will crash anyway when it tries to instantiate
+// NSSCertDatabase with a nullptr public slot, crashing early can provide better
+// logs/stacktraces for diagnosing.
+// Takes `nss_path` where NSS is supposed to be (or created). Will attempt
+// creating the path if it doesn't exist (to check that it can be done).
+// Theoretically the path should already exist because it's created when Chrome
+// tries to open the public slot.
+CRYPTO_EXPORT void DiagnosePublicSlotAndCrash(const base::FilePath& nss_path);
+
+#endif  // BUILDFLAG(IS_CHROMEOS_ASH)
 
 // Convert a NSS PRTime value into a base::Time object.
 // We use a int64_t instead of PRTime here to avoid depending on NSPR headers.
