@@ -5,18 +5,16 @@
 #ifndef NET_BASE_PROXY_SERVER_H_
 #define NET_BASE_PROXY_SERVER_H_
 
-#include "build/build_config.h"
-
-#if defined(OS_APPLE)
-#include <CoreFoundation/CoreFoundation.h>
-#endif
+#include <stdint.h>
 
+#include <ostream>
 #include <string>
 #include <tuple>
 
 #include "base/strings/string_piece.h"
 #include "net/base/host_port_pair.h"
 #include "net/base/net_export.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
 
 namespace net {
 
@@ -46,6 +44,29 @@ class NET_EXPORT ProxyServer {
 
   ProxyServer(Scheme scheme, const HostPortPair& host_port_pair);
 
+  // Creates a ProxyServer, validating and canonicalizing input. Port is
+  // optional and, if not provided, will be replaced with the default port for
+  // the given scheme. Accepts IPv6 literal `host`s with surrounding brackets
+  // (URL format) or without (HostPortPair format). On invalid input, result
+  // will be a `SCHEME_INVALID` ProxyServer.
+  //
+  // Must not be called with `SCHEME_INVALID` or `SCHEME_DIRECT`. Use
+  // `ProxyServer()` or `Direct()` respectively to create an invalid or direct
+  // ProxyServer.
+  static ProxyServer FromSchemeHostAndPort(Scheme scheme,
+                                           base::StringPiece host,
+                                           base::StringPiece port_str);
+  static ProxyServer FromSchemeHostAndPort(Scheme scheme,
+                                           base::StringPiece host,
+                                           absl::optional<uint16_t> port);
+
+  // In URL format (with brackets around IPv6 literals). Must not call for
+  // ProxyServers without a host (invalid or direct).
+  std::string GetHost() const;
+
+  // Must not call for ProxyServers without a host (invalid or direct).
+  uint16_t GetPort() const;
+
   bool is_valid() const { return scheme_ != SCHEME_INVALID; }
 
   // Gets the proxy's scheme (i.e. SOCKS4, SOCKS5, HTTP)
@@ -82,76 +103,15 @@ class NET_EXPORT ProxyServer {
 
   const HostPortPair& host_port_pair() const;
 
-  // Parses from an input with format:
-  //   [<scheme>"://"]<server>[":"<port>]
-  //
-  // Both <scheme> and <port> are optional. If <scheme> is omitted, it will be
-  // assumed as |default_scheme|. If <port> is omitted, it will be assumed as
-  // the default port for the chosen scheme (80 for "http", 1080 for "socks").
-  //
-  // If parsing fails the instance will be set to invalid.
-  //
-  // Examples (for |default_scheme| = SCHEME_HTTP ):
-  //   "foopy"            {scheme=HTTP, host="foopy", port=80}
-  //   "socks://foopy"    {scheme=SOCKS5, host="foopy", port=1080}
-  //   "socks4://foopy"   {scheme=SOCKS4, host="foopy", port=1080}
-  //   "socks5://foopy"   {scheme=SOCKS5, host="foopy", port=1080}
-  //   "http://foopy:17"  {scheme=HTTP, host="foopy", port=17}
-  //   "https://foopy:17" {scheme=HTTPS, host="foopy", port=17}
-  //   "quic://foopy:17"  {scheme=QUIC, host="foopy", port=17}
-  //   "direct://"        {scheme=DIRECT}
-  //   "foopy:X"          INVALID -- bad port.
-  static ProxyServer FromURI(base::StringPiece uri, Scheme default_scheme);
-
-  // Formats as a URI string. This does the reverse of FromURI.
-  std::string ToURI() const;
-
-  // Parses from a PAC string result.
-  //
-  // If <port> is omitted, it will be assumed as the default port for the
-  // chosen scheme (80 for "http", 1080 for "socks").
-  //
-  // If parsing fails the instance will be set to invalid.
-  //
-  // Examples:
-  //   "PROXY foopy:19"   {scheme=HTTP, host="foopy", port=19}
-  //   "DIRECT"           {scheme=DIRECT}
-  //   "SOCKS5 foopy"     {scheme=SOCKS5, host="foopy", port=1080}
-  //   "HTTPS foopy:123"  {scheme=HTTPS, host="foopy", port=123}
-  //   "QUIC foopy:123"   {scheme=QUIC, host="foopy", port=123}
-  //   "BLAH xxx:xx"      INVALID
-  static ProxyServer FromPacString(base::StringPiece pac_string);
-
   // Returns a ProxyServer representing DIRECT connections.
   static ProxyServer Direct() {
     return ProxyServer(SCHEME_DIRECT, HostPortPair());
   }
 
-#if defined(OS_APPLE)
-  // Utility function to pull out a host/port pair from a dictionary and return
-  // it as a ProxyServer object. Pass in a dictionary that has a  value for the
-  // host key and optionally a value for the port key. In the error condition
-  // where the host value is especially malformed, returns an invalid
-  // ProxyServer.
-  static ProxyServer FromDictionary(Scheme scheme,
-                                    CFDictionaryRef dict,
-                                    CFStringRef host_key,
-                                    CFStringRef port_key);
-#endif
-
-  // Formats as a PAC result entry. This does the reverse of FromPacString().
-  std::string ToPacString() const;
-
   // Returns the default port number for a proxy server with the specified
   // scheme. Returns -1 if unknown.
   static int GetDefaultPortForScheme(Scheme scheme);
 
-  // Parses the proxy scheme from a URL-like representation, to a
-  // ProxyServer::Scheme. This corresponds with the values used in
-  // ProxyServer::ToURI(). If no type could be matched, returns SCHEME_INVALID.
-  // |scheme| can be one of http, https, socks, socks4, socks5, direct.
-  static Scheme GetSchemeFromURI(const std::string& scheme);
-
   bool operator==(const ProxyServer& other) const {
     return scheme_ == other.scheme_ &&
            host_port_pair_.Equals(other.host_port_pair_);
@@ -166,15 +126,13 @@ class NET_EXPORT ProxyServer {
   }
 
  private:
-  // Creates a ProxyServer given a scheme, and host/port string. If parsing the
-  // host/port string fails, the returned instance will be invalid.
-  static ProxyServer FromSchemeHostAndPort(Scheme scheme,
-                                           base::StringPiece host_and_port);
-
   Scheme scheme_ = SCHEME_INVALID;
   HostPortPair host_port_pair_;
 };
 
+NET_EXPORT_PRIVATE std::ostream& operator<<(std::ostream& os,
+                                            const ProxyServer& proxy_server);
+
 typedef std::pair<HostPortPair, ProxyServer> HostPortProxyPair;
 
 }  // namespace net
