@@ -163,20 +163,14 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
 }
 
 #if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
-
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot(
+    std::unique_ptr<TrustStoreChrome> chrome_root) {
   return std::make_unique<SystemTrustStoreChrome>(
-      std::make_unique<TrustStoreChrome>(),
+      std::move(chrome_root),
       std::make_unique<TrustStoreNSS>(
           trustSSL, TrustStoreNSS::IgnoreSystemTrustSettings()));
 }
 
-#else
-
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
-  return std::make_unique<DummySystemTrustStore>();
-}
-
 #endif  // CHROME_ROOT_STORE_SUPPORTED
 
 std::unique_ptr<SystemTrustStore>
@@ -214,7 +208,7 @@ class SystemTrustStoreMac : public SystemTrustStore {
 
  private:
   static constexpr TrustStoreMac::TrustImplType kDefaultTrustImpl =
-      TrustStoreMac::TrustImplType::kDomainCache;
+      TrustStoreMac::TrustImplType::kLruCache;
 
   static TrustStoreMac::TrustImplType ParamToTrustImplType(int param) {
     switch (param) {
@@ -264,10 +258,6 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<SystemTrustStoreMac>();
 }
 
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
-  return std::make_unique<DummySystemTrustStore>();
-}
-
 void InitializeTrustStoreMacCache() {
   base::ThreadPool::PostTask(
       FROM_HERE,
@@ -336,10 +326,6 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<SystemTrustStoreFuchsia>();
 }
 
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
-  return std::make_unique<DummySystemTrustStore>();
-}
-
 #elif BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_ANDROID)
 
 namespace {
@@ -488,9 +474,10 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
 
 #if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
 
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot(
+    std::unique_ptr<TrustStoreChrome> chrome_root) {
   return std::make_unique<SystemTrustStoreChrome>(
-      std::make_unique<TrustStoreChrome>(), StaticUnixSystemCerts::Create());
+      std::move(chrome_root), StaticUnixSystemCerts::Create());
 }
 
 #else
@@ -511,15 +498,10 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
 
 #if BUILDFLAG(CHROME_ROOT_STORE_SUPPORTED)
 
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
-  return std::make_unique<SystemTrustStoreChrome>(
-      std::make_unique<TrustStoreChrome>(), TrustStoreWin::Create());
-}
-
-#else
-
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
-  return std::make_unique<DummySystemTrustStore>();
+std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot(
+    std::unique_ptr<TrustStoreChrome> chrome_root) {
+  return std::make_unique<SystemTrustStoreChrome>(std::move(chrome_root),
+                                                  TrustStoreWin::Create());
 }
 
 #endif  // CHROME_ROOT_STORE_SUPPORTED
@@ -530,10 +512,6 @@ std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStore() {
   return std::make_unique<DummySystemTrustStore>();
 }
 
-std::unique_ptr<SystemTrustStore> CreateSslSystemTrustStoreChromeRoot() {
-  return std::make_unique<DummySystemTrustStore>();
-}
-
 #endif
 
 std::unique_ptr<SystemTrustStore> CreateEmptySystemTrustStore() {
