@@ -19,15 +19,6 @@ class X509Certificate;
 
 namespace x509_util {
 
-// Creates a SecCertificate handle from the DER-encoded representation.
-// Returns NULL on failure.
-NET_EXPORT base::ScopedCFTypeRef<SecCertificateRef>
-CreateSecCertificateFromBytes(const uint8_t* data, size_t length);
-
-// Returns a SecCertificate representing |cert|, or NULL on failure.
-NET_EXPORT base::ScopedCFTypeRef<SecCertificateRef>
-CreateSecCertificateFromX509Certificate(const X509Certificate* cert);
-
 // Creates an X509Certificate representing |sec_cert| with intermediates
 // |sec_chain|.
 NET_EXPORT scoped_refptr<X509Certificate>
