@@ -4,6 +4,8 @@
 
 #include "net/dns/public/dns_query_type.h"
 
+#include "base/check.h"
+
 namespace net {
 
 bool IsAddressType(DnsQueryType dns_query_type) {
@@ -14,4 +16,11 @@ bool IsAddressType(DnsQueryType dns_query_type) {
          dns_query_type == DnsQueryType::AAAA;
 }
 
+bool HasAddressType(DnsQueryTypeSet dns_query_types) {
+  DCHECK(!dns_query_types.Empty());
+  DCHECK(!dns_query_types.Has(DnsQueryType::UNSPECIFIED));
+  return dns_query_types.Has(DnsQueryType::A) ||
+         dns_query_types.Has(DnsQueryType::AAAA);
+}
+
 }  // namespace net
