@@ -11,7 +11,7 @@
 
 #include "base/callback.h"
 #include "base/compiler_specific.h"
-#include "base/macros.h"
+#include "base/memory/raw_ptr.h"
 #include "net/log/net_log.h"
 #include "net/log/net_log_event_type.h"
 
@@ -72,7 +72,7 @@ class RecordingNetLogObserver : public NetLog::ThreadSafeObserver {
  private:
   mutable base::Lock lock_;
   std::vector<NetLogEntry> entry_list_;
-  NetLog* const net_log_;
+  const raw_ptr<NetLog> net_log_;
   base::RepeatingClosure add_entry_callback_;
 };
 
