@@ -16,31 +16,36 @@ QuicSessionKey::QuicSessionKey(const HostPortPair& host_port_pair,
                                PrivacyMode privacy_mode,
                                const SocketTag& socket_tag,
                                const NetworkIsolationKey& network_isolation_key,
-                               SecureDnsPolicy secure_dns_policy)
+                               SecureDnsPolicy secure_dns_policy,
+                               bool require_dns_https_alpn)
     : QuicSessionKey(host_port_pair.host(),
                      host_port_pair.port(),
                      privacy_mode,
                      socket_tag,
                      network_isolation_key,
-                     secure_dns_policy) {}
+                     secure_dns_policy,
+                     require_dns_https_alpn) {}
 
 QuicSessionKey::QuicSessionKey(const std::string& host,
                                uint16_t port,
                                PrivacyMode privacy_mode,
                                const SocketTag& socket_tag,
                                const NetworkIsolationKey& network_isolation_key,
-                               SecureDnsPolicy secure_dns_policy)
+                               SecureDnsPolicy secure_dns_policy,
+                               bool require_dns_https_alpn)
     : QuicSessionKey(
           // TODO(crbug.com/1103350): Handle non-boolean privacy modes.
           quic::QuicServerId(host, port, privacy_mode != PRIVACY_MODE_DISABLED),
           socket_tag,
           network_isolation_key,
-          secure_dns_policy) {}
+          secure_dns_policy,
+          require_dns_https_alpn) {}
 
 QuicSessionKey::QuicSessionKey(const quic::QuicServerId& server_id,
                                const SocketTag& socket_tag,
                                const NetworkIsolationKey& network_isolation_key,
-                               SecureDnsPolicy secure_dns_policy)
+                               SecureDnsPolicy secure_dns_policy,
+                               bool require_dns_https_alpn)
     : server_id_(server_id),
       socket_tag_(socket_tag),
       network_isolation_key_(
@@ -48,20 +53,23 @@ QuicSessionKey::QuicSessionKey(const quic::QuicServerId& server_id,
               features::kPartitionConnectionsByNetworkIsolationKey)
               ? network_isolation_key
               : NetworkIsolationKey()),
-      secure_dns_policy_(secure_dns_policy) {}
+      secure_dns_policy_(secure_dns_policy),
+      require_dns_https_alpn_(require_dns_https_alpn) {}
 
 QuicSessionKey::QuicSessionKey(const QuicSessionKey& other) = default;
 
 bool QuicSessionKey::operator<(const QuicSessionKey& other) const {
   return std::tie(server_id_, socket_tag_, network_isolation_key_,
-                  secure_dns_policy_) <
+                  secure_dns_policy_, require_dns_https_alpn_) <
          std::tie(other.server_id_, other.socket_tag_,
-                  other.network_isolation_key_, other.secure_dns_policy_);
+                  other.network_isolation_key_, other.secure_dns_policy_,
+                  other.require_dns_https_alpn_);
 }
 bool QuicSessionKey::operator==(const QuicSessionKey& other) const {
   return server_id_ == other.server_id_ && socket_tag_ == other.socket_tag_ &&
          network_isolation_key_ == other.network_isolation_key_ &&
-         secure_dns_policy_ == other.secure_dns_policy_;
+         secure_dns_policy_ == other.secure_dns_policy_ &&
+         require_dns_https_alpn_ == other.require_dns_https_alpn_;
 }
 
 bool QuicSessionKey::CanUseForAliasing(const QuicSessionKey& other) const {
@@ -69,7 +77,8 @@ bool QuicSessionKey::CanUseForAliasing(const QuicSessionKey& other) const {
              other.server_id_.privacy_mode_enabled() &&
          socket_tag_ == other.socket_tag_ &&
          network_isolation_key_ == other.network_isolation_key_ &&
-         secure_dns_policy_ == other.secure_dns_policy_;
+         secure_dns_policy_ == other.secure_dns_policy_ &&
+         require_dns_https_alpn_ == other.require_dns_https_alpn_;
 }
 
 }  // namespace net
