@@ -9,6 +9,7 @@
 
 #include "base/bind.h"
 #include "base/containers/flat_set.h"
+#include "base/memory/raw_ptr.h"
 #include "base/time/tick_clock.h"
 #include "base/time/time.h"
 #include "base/timer/timer.h"
@@ -42,7 +43,10 @@ class ReportingGarbageCollectorImpl : public ReportingGarbageCollector,
 
   // ReportingObserver implementation:
   void OnReportsUpdated() override { EnsureTimerIsRunning(); }
-  void OnEndpointsUpdated() override { EnsureTimerIsRunning(); }
+  void OnEndpointsUpdatedForOrigin(
+      const std::vector<ReportingEndpoint>& endpoints) override {
+    EnsureTimerIsRunning();
+  }
 
  private:
   // TODO(crbug.com/912622): Garbage collect clients, reports with no matching
@@ -87,7 +91,7 @@ class ReportingGarbageCollectorImpl : public ReportingGarbageCollector,
                                  base::Unretained(this)));
   }
 
-  ReportingContext* context_;
+  raw_ptr<ReportingContext> context_;
   std::unique_ptr<base::OneShotTimer> timer_;
 };
 
