@@ -8,9 +8,12 @@
 #include "base/files/file_util.h"
 #include "base/threading/thread_restrictions.h"
 #include "net/cert/ev_root_ca_metadata.h"
+#include "net/cert/pem.h"
 #include "net/cert/x509_certificate.h"
 #include "net/cert/x509_util.h"
 #include "net/test/test_data_directory.h"
+#include "third_party/boringssl/src/include/openssl/bytestring.h"
+#include "third_party/boringssl/src/include/openssl/evp.h"
 
 namespace net {
 
@@ -61,10 +64,8 @@ scoped_refptr<X509Certificate> CreateCertificateChainFromFile(
 }
 
 scoped_refptr<X509Certificate> ImportCertFromFile(
-    const base::FilePath& certs_dir,
-    base::StringPiece cert_file) {
+    const base::FilePath& cert_path) {
   base::ScopedAllowBlockingForTesting allow_blocking;
-  base::FilePath cert_path = certs_dir.AppendASCII(cert_file);
   std::string cert_data;
   if (!base::ReadFileToString(cert_path, &cert_data))
     return nullptr;
@@ -78,6 +79,28 @@ scoped_refptr<X509Certificate> ImportCertFromFile(
   return certs_in_file[0];
 }
 
+scoped_refptr<X509Certificate> ImportCertFromFile(
+    const base::FilePath& certs_dir,
+    base::StringPiece cert_file) {
+  return ImportCertFromFile(certs_dir.AppendASCII(cert_file));
+}
+
+bssl::UniquePtr<EVP_PKEY> LoadPrivateKeyFromFile(
+    const base::FilePath& key_path) {
+  std::string key_string;
+  if (!base::ReadFileToString(key_path, &key_string))
+    return nullptr;
+  std::vector<std::string> headers;
+  headers.push_back("PRIVATE KEY");
+  PEMTokenizer pem_tokenizer(key_string, headers);
+  if (!pem_tokenizer.GetNext())
+    return nullptr;
+  CBS cbs;
+  CBS_init(&cbs, reinterpret_cast<const uint8_t*>(pem_tokenizer.data().data()),
+           pem_tokenizer.data().size());
+  return bssl::UniquePtr<EVP_PKEY>(EVP_parse_private_key(&cbs));
+}
+
 ScopedTestEVPolicy::ScopedTestEVPolicy(EVRootCAMetadata* ev_root_ca_metadata,
                                        const SHA256HashValue& fingerprint,
                                        const char* policy)
