@@ -22,6 +22,7 @@
 #include "base/logging.h"
 #include "base/memory/weak_ptr.h"
 #include "base/path_service.h"
+#include "base/strings/escape.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_split.h"
 #include "base/strings/string_util.h"
@@ -30,7 +31,6 @@
 #include "base/threading/thread_task_runner_handle.h"
 #include "base/time/time.h"
 #include "base/unguessable_token.h"
-#include "net/base/escape.h"
 #include "net/base/host_port_pair.h"
 #include "net/base/url_util.h"
 #include "net/filter/filter_source_stream_test_util.h"
@@ -305,8 +305,9 @@ std::unique_ptr<HttpResponse> HandleExpectAndSetCookie(
   if (got_all_expected) {
     for (const auto& cookie : query_list.at("set")) {
       http_response->AddCustomHeader(
-          "Set-Cookie", base::UnescapeBinaryURLComponent(
-                            cookie, UnescapeRule::REPLACE_PLUS_WITH_SPACE));
+          "Set-Cookie",
+          base::UnescapeBinaryURLComponent(
+              cookie, base::UnescapeRule::REPLACE_PLUS_WITH_SPACE));
     }
   }
 
@@ -645,16 +646,18 @@ std::unique_ptr<HttpResponse> HandleServerRedirectWithSecureCookie(
   return http_response;
 }
 
-// /cross-site?URL
+// /cross-site?URL (also /cross-site-with-cookie?URL)
 // Returns a cross-site redirect to URL.
 std::unique_ptr<HttpResponse> HandleCrossSiteRedirect(
     EmbeddedTestServer* server,
+    const std::string& prefix,
+    bool set_cookie,
     const HttpRequest& request) {
-  if (!ShouldHandle(request, "/cross-site"))
+  if (!ShouldHandle(request, prefix))
     return nullptr;
 
   std::string dest_all = base::UnescapeBinaryURLComponent(
-      request.relative_url.substr(std::string("/cross-site").size() + 1));
+      request.relative_url.substr(prefix.size() + 1));
 
   std::string dest;
   size_t delimiter = dest_all.find("/");
@@ -667,6 +670,9 @@ std::unique_ptr<HttpResponse> HandleCrossSiteRedirect(
   auto http_response = std::make_unique<BasicHttpResponse>();
   http_response->set_code(HTTP_MOVED_PERMANENTLY);
   http_response->AddCustomHeader("Location", dest);
+  if (set_cookie) {
+    http_response->AddCustomHeader("Set-Cookie", "server-redirect=true");
+  }
   http_response->set_content_type("text/html");
   http_response->set_content(base::StringPrintf(
       "<html><head></head><body>Redirecting to %s</body></html>",
@@ -996,8 +1002,12 @@ void RegisterDefaultHandlers(EmbeddedTestServer* server) {
       "/server-redirect-with-secure-cookie",
       &HandleServerRedirectWithSecureCookie, HTTP_MOVED_PERMANENTLY));
 
+  server->RegisterDefaultHandler(base::BindRepeating(&HandleCrossSiteRedirect,
+                                                     server, "/cross-site",
+                                                     /*set_cookie=*/false));
   server->RegisterDefaultHandler(
-      base::BindRepeating(&HandleCrossSiteRedirect, server));
+      base::BindRepeating(&HandleCrossSiteRedirect, server,
+                          "/cross-site-with-cookie", /*set_cookie=*/true));
   server->RegisterDefaultHandler(
       PREFIXED_HANDLER("/client-redirect", &HandleClientRedirect));
   server->RegisterDefaultHandler(
