@@ -143,7 +143,7 @@ int TestURLFetcher::GetMaxRetriesOn5xx() const {
 }
 
 base::TimeDelta TestURLFetcher::GetBackoffDelay() const {
-  return fake_backoff_delay_;
+  return base::TimeDelta();
 }
 
 void TestURLFetcher::SetAutomaticallyRetryOnNetworkChanges(int max_retries) {
@@ -288,10 +288,6 @@ void TestURLFetcher::set_response_headers(
   fake_response_headers_ = headers;
 }
 
-void TestURLFetcher::set_backoff_delay(base::TimeDelta backoff_delay) {
-  fake_backoff_delay_ = backoff_delay;
-}
-
 void TestURLFetcher::SetDelegateForTests(DelegateForTests* delegate_for_tests) {
   delegate_for_tests_ = delegate_for_tests;
 }
