@@ -37,14 +37,6 @@ namespace url {
 class Origin;
 }
 
-namespace cloud_print {
-class CloudPrintURLFetcher;
-}
-
-namespace device {
-class UsbTestGadgetImpl;
-}
-
 namespace remoting {
 class GstaticJsonFetcher;
 }
@@ -344,8 +336,6 @@ class NET_EXPORT URLFetcher {
  private:
   // This class is deprecated, and no new code should be using it. Construction
   // methods are private and pre-existing consumers are friended.
-  friend class cloud_print::CloudPrintURLFetcher;
-  friend class device::UsbTestGadgetImpl;
   friend class remoting::GstaticJsonFetcher;
 
   // The unannotated Create() methods are not available on desktop Linux +
