@@ -372,8 +372,11 @@ std::unique_ptr<URLRequestContext> URLRequestContextBuilder::Build() {
     set_client_socket_factory(client_socket_factory.get());
     storage->set_client_socket_factory(std::move(client_socket_factory));
 
+    HostResolver::ManagerOptions manager_options;
+    manager_options.insecure_dns_client_enabled = false;
+    manager_options.additional_types_via_insecure_dns_enabled = false;
     host_resolver_ = HostResolver::CreateStandaloneNetworkBoundResolver(
-        context->net_log(), bound_network_);
+        context->net_log(), bound_network_, manager_options);
 
     if (!quic_context_)
       set_quic_context(std::make_unique<QuicContext>());
@@ -603,8 +606,9 @@ std::unique_ptr<URLRequestContext> URLRequestContextBuilder::Build() {
           break;
       }
       http_cache_backend = std::make_unique<HttpCache::DefaultBackend>(
-          DISK_CACHE, backend_type, http_cache_params_.path,
-          http_cache_params_.max_size, http_cache_params_.reset_cache);
+          DISK_CACHE, backend_type, http_cache_params_.file_operations_factory,
+          http_cache_params_.path, http_cache_params_.max_size,
+          http_cache_params_.reset_cache);
     } else {
       http_cache_backend =
           HttpCache::DefaultBackend::InMemory(http_cache_params_.max_size);
@@ -614,9 +618,8 @@ std::unique_ptr<URLRequestContext> URLRequestContextBuilder::Build() {
         http_cache_params_.app_status_listener);
 #endif
 
-    http_transaction_factory =
-        std::make_unique<HttpCache>(std::move(http_transaction_factory),
-                                    std::move(http_cache_backend), true);
+    http_transaction_factory = std::make_unique<HttpCache>(
+        std::move(http_transaction_factory), std::move(http_cache_backend));
   }
   storage->set_http_transaction_factory(std::move(http_transaction_factory));
 
