@@ -33,6 +33,7 @@
 #include "net/base/network_change_notifier.h"
 #include "net/base/network_delegate.h"
 #include "net/base/proxy_delegate.h"
+#include "net/disk_cache/disk_cache.h"
 #include "net/dns/host_resolver.h"
 #include "net/http/http_network_session.h"
 #include "net/net_buildflags.h"
@@ -121,6 +122,11 @@ class NET_EXPORT URLRequestContextBuilder {
     // The cache path (when type is DISK).
     base::FilePath path;
 
+    // A factory to broker file operations. This is needed for network process
+    // sandboxing in some platforms.
+    scoped_refptr<disk_cache::BackendFileOperationsFactory>
+        file_operations_factory;
+
 #if BUILDFLAG(IS_ANDROID)
     // If this is set, will override the default ApplicationStatusListener. This
     // is useful if the cache will not be in the main process.
