@@ -8,6 +8,7 @@
 
 #include "base/bind.h"
 #include "base/logging.h"
+#include "base/memory/raw_ptr.h"
 #include "base/memory/weak_ptr.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/time/time.h"
@@ -76,7 +77,7 @@ class Delegate : public URLRequest::Delegate {
   void OnAuthRequiredComplete(URLRequest* request,
                               const AuthCredentials* auth_credentials);
 
-  WebSocketStreamRequestImpl* owner_;
+  raw_ptr<WebSocketStreamRequestImpl> owner_;
 };
 
 class WebSocketStreamRequestImpl : public WebSocketStreamRequestAPI {
