@@ -209,15 +209,18 @@ class NodeUnittest(unittest.TestCase):
     AssertExpr(True, "'foo' in defs", {'foo': 'bar'}, 'ios', {})
     AssertExpr(False, "'foo' in defs", {'baz': 'bar'}, 'ios', {})
     AssertExpr(False, "'foo' in defs", {}, 'ios', {})
-    AssertExpr(True, "is_linux", {}, 'linux2', {})
-    AssertExpr(True, "is_linux", {'is_chromeos': True}, 'linux2', {})
-    AssertExpr(True, "is_linux", {'chromeos': True}, 'linux2', {})
-    AssertExpr(True, "is_linux", {'lacros': True}, 'linux2', {})
-    # TODO(crbug.com/1307455): These two should be False once fixed.
-    AssertExpr(True, "is_linux", {'chromeos_ash': True}, 'linux2', {})
-    AssertExpr(True, "is_linux", {'chromeos_lacros': True}, 'linux2', {})
-    AssertExpr(False, "is_chromeos", {}, 'linux2', {})
-    AssertExpr(False, "is_fuchsia", {}, 'linux2', {})
+    AssertExpr(True, "is_linux", {}, 'linux', {})
+    AssertExpr(False, "is_linux", {}, 'linux2', {})  # Python 2 used 'linux2'.
+    AssertExpr(False, "is_linux", {}, 'linux-foo', {})  # Must match exactly.
+    AssertExpr(False, "is_linux", {}, 'foollinux', {})
+    # TODO(crbug.com/1307455): is_linux should be false for Chrome OS once the
+    # bug is fixed. However, this exact expression may not change. Update to
+    # test the actual conditions for Chrome OS.
+    AssertExpr(True, "is_linux", {'chromeos_ash': True}, 'linux', {})
+    AssertExpr(True, "is_linux", {'chromeos_lacros': True}, 'linux', {})
+    AssertExpr(False, "is_chromeos", {'is_chromeos': False}, 'linux', {})
+    AssertExpr(True, "is_linux", {'is_chromeos': True}, 'linux', {})
+    AssertExpr(False, "is_fuchsia", {}, 'linux', {})
     AssertExpr(False, "is_linux", {}, 'win32', {})
     AssertExpr(True, "is_macosx", {}, 'darwin', {})
     AssertExpr(False, "is_macosx", {}, 'ios', {})
@@ -227,9 +230,9 @@ class NodeUnittest(unittest.TestCase):
     AssertExpr(False, "is_android", {}, 'linux3', {})
     AssertExpr(True, "is_ios", {}, 'ios', {})
     AssertExpr(False, "is_ios", {}, 'darwin', {})
-    AssertExpr(True, "is_posix", {}, 'linux2', {})
-    AssertExpr(True, "is_posix", {'chromeos_ash': True}, 'linux2', {})
-    AssertExpr(True, "is_posix", {'chromeos_lacros': True}, 'linux2', {})
+    AssertExpr(True, "is_posix", {}, 'linux', {})
+    AssertExpr(True, "is_posix", {'chromeos_ash': True}, 'linux', {})
+    AssertExpr(True, "is_posix", {'chromeos_lacros': True}, 'linux', {})
     AssertExpr(True, "is_posix", {}, 'darwin', {})
     AssertExpr(True, "is_posix", {}, 'android', {})
     AssertExpr(True, "is_posix", {}, 'ios', {})
@@ -245,27 +248,51 @@ class NodeUnittest(unittest.TestCase):
     AssertExpr(False, "pp_if('foo')", {'bar': True}, 'win32', {})
     AssertExpr(True, "foo", {'foo': True}, 'win32', {})
     AssertExpr(False, "foo", {'foo': False}, 'win32', {})
-    AssertExpr(False, "foo", {'bar': True}, 'win32', {})
+    AssertExpr(False, "foo", {'bar': True, 'foo': False}, 'win32', {})
     AssertExpr(True, "foo == 'baz'", {'foo': 'baz'}, 'win32', {})
     AssertExpr(False, "foo == 'baz'", {'foo': True}, 'win32', {})
-    AssertExpr(False, "foo == 'baz'", {}, 'win32', {})
+    AssertExpr(False, "foo == 'baz'", {'foo': True, 'baz': False}, 'win32', {})
     AssertExpr(True, "lang == 'de'", {}, 'win32', {'lang': 'de'})
     AssertExpr(False, "lang == 'de'", {}, 'win32', {'lang': 'fr'})
-    AssertExpr(False, "lang == 'de'", {}, 'win32', {})
 
     # Test a couple more complex expressions for good measure.
     AssertExpr(True, "is_ios and (lang in ['de', 'fr'] or foo)",
                {'foo': 'bar'}, 'ios', {'lang': 'fr', 'context': 'today'})
     AssertExpr(False, "is_ios and (lang in ['de', 'fr'] or foo)",
-               {'foo': False}, 'linux2', {'lang': 'fr', 'context': 'today'})
-    AssertExpr(False, "is_ios and (lang in ['de', 'fr'] or foo)",
-               {'baz': 'bar'}, 'ios', {'lang': 'he', 'context': 'today'})
-    AssertExpr(True, "foo == 'bar' or not baz",
-               {'foo': 'bar', 'fun': True}, 'ios', {'lang': 'en'})
-    AssertExpr(True, "foo == 'bar' or not baz",
-               {}, 'ios', {'lang': 'en', 'context': 'java'})
+               {'foo': False}, 'linux', {
+                   'lang': 'fr',
+                   'context': 'today'
+               })
+    AssertExpr(False, "is_ios and (lang in ['de', 'fr'] or foo)", {
+        'baz': 'bar',
+        'is_ios': True,
+        'foo': False
+    }, 'ios', {
+        'lang': 'he',
+        'context': 'today'
+    })
+    AssertExpr(True, "foo == 'bar' or not baz", {
+        'foo': 'bar',
+        'baz': True
+    }, 'ios', {
+        'lang': 'en',
+        'context': 'java'
+    })
     AssertExpr(False, "foo == 'bar' or not baz",
                {'foo': 'ruz', 'baz': True}, 'ios', {'lang': 'en'})
 
+  def testEvaluateExpressionWithUndefinedVariables(self):
+    def AssertThrows(expr, defs):
+      with self.assertRaises(AssertionError) as cm:
+        base.Node.EvaluateExpression(expr, defs, 'linux', {})
+      self.assertTrue(
+          str(cm.exception).startswith('undefined Grit variable found:'))
+
+    AssertThrows("is_chromeos", {})
+    AssertThrows("foo == 'baz'", {})
+    AssertThrows("is_chromeos", {'is_macosx': True})
+    AssertThrows("foo == 'bar' or not baz", {'foo': 'bar', 'fun': True})
+
+
 if __name__ == '__main__':
   unittest.main()
